Learn R Programming

ibdreg (version 0.2.5)

print.linkage.all: Print or summarize a linkage.all object

Description

Print a linkage.all object, made within ibdreg. For the linkage test, print the test statistic, degrees of freedom, and pvalue at the position with the smallest pvalue.

Usage

# S3 method for linkage.all
print(x, digits=max(options()$digits - 2, 5), ...)

Arguments

x

A linkage.all object

digits

number of significant digits to print for numeric values

additional display parameters

Value

nothing is returned

See Also

ibdreg, linkage.all, plot.linkage.all